@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::Perl::Loader;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use constant DEBUG => ($ENV{YAML_PP_LOAD_DEBUG} or $ENV{YAML_PP_LOAD_TRACE}) ? 1 : 0;
 use constant TRACE => $ENV{YAML_PP_LOAD_TRACE} ? 1 : 0;
@@ -99,14 +99,14 @@ sub begin {
     }
 }
 
-sub begin_doc {
+sub document_start_event {
     my ($self, $event) = @_;
     $self->set_data(undef);
     $self->set_refs([ \$self->{data} ]);
     $self->set_anchors({});
 }
 
-sub end_doc {
+sub document_end_event {
     my ($self, $event) = @_;
     my $refs = $self->refs;
     my $docs = $self->docs;
@@ -114,33 +114,33 @@ sub end_doc {
     pop @$refs if @$refs;
 }
 
-sub begin_map {
+sub mapping_start_event {
     my ($self, $event) = @_;
     my $data = {};
     shift->begin($data, @_);
 }
 
-sub end_map {
+sub mapping_end_event {
     shift->end(@_);
 }
 
-sub begin_seq {
+sub sequence_start_event {
     my ($self, $event) = @_;
     my $data = [];
     shift->begin($data, @_);
 }
 
-sub end_seq {
+sub sequence_end_event {
     shift->end(@_);
 }
 
-sub begin_str {
+sub stream_start_event {
     my ($self, $event) = @_;
     my $refs = $self->refs;
     pop @$refs if @$refs;
 }
 
-sub end_str {}
+sub stream_end_event {}
 
 sub end {
     my ($self, $event) = @_;
@@ -165,7 +165,7 @@ sub end {
 }
 
 
-sub value {
+sub scalar_event {
     my ($self, $event) = @_;
     my $value = $self->render_value($event);
     $self->event(value => $value, event => $event);
